import {Component, Event, EventEmitter, h} from '@stencil/core';
import { Prop } from '@stencil/core';
import { State } from '@stencil/core';
import {MonobankLangListInterface} from "../../../index";

@Component({
  tag: 's-cnt-monobank-lang-selector',
  styleUrl: 's-cnt-monobank-lang-selector.css',
  shadow: false,
  scoped: true,
})
export class SCntMonobankLangSelector {
  /**
   *Списко языков
   */
  @Prop() langList:  MonobankLangListInterface[];

  /**
   *
   * */
  @Prop() theme: 'top' | 'main' = 'top';

  /**
   * Стейт для переключения селектора языков
   */
  @State() langSelectorToggleState: boolean = false;

  /**
   * Последний кликнутый айтем селектора языков
   */
  @State() lastClickedItemState: number = 1;

  /**
   * Клик по языка селектора
   */
  @Event() clickOnLangListItem: EventEmitter;

  /**
   * Реф для селектора языков
   */
  public langSelectorTag: HTMLElement;

  render() {
    return (
      <div class={this.getClassForHost()}>
        <div class="lang-selector" ref={el => (this.langSelectorTag = el)}>
          <div class="lang-selector-inner" >
            <LangSelectorItemFunctionalComponent
              array={this.langList}
              lastClickedItemState={this.lastClickedItemState}
              clickOnLangListItemHandler={(event) => this.clickOnLangListItemHandler(event)}
            />
          </div>
        </div>
      </div>
    );
  }

  /**
   *
   * */
  public getClassForHost() {
    return {
      [this.theme]: true,
    };
  }

  /**
   * Показать или скрыть все языки
   */
  public showOrHideLangSelectorItems() {
    this.langSelectorToggleState = !this.langSelectorToggleState;
    this.addOrRemoveClassForLangSelector();
  }

  /**
   * Удаление и добавление класса для селектора языков
   */
  public addOrRemoveClassForLangSelector() {
    if (this.langSelectorToggleState === true) {
      this.langSelectorTag.classList.add('opened');
    } else {
      this.langSelectorTag.classList.remove('opened');
    }
  }

  /**
   *
   */
  public clickOnLangListItemHandler(event) {
    this.showOrHideLangSelectorItems();
    this.clickOnLangListItem.emit(event);
  }
}

const LangSelectorItemFunctionalComponent = props => {
  return props.array.map(item => {
    return (
      <a onClick={(event) => props.clickOnLangListItemHandler(event)}
         class={`lang-selector-item ${item.id === props.lastClickedItemState && 'active'}`}
         href={item.link}
      >
        {item.lang}
      </a>
    );
  });
};
